.biom, or if
you happen to know that it is a biom-format file, or if
you used default settings in a version of QIIME of
1.7 or greater, then YOU SHOULD USE THE
BIOM-IMPORT FUNCTION instead, import_biom.
import_qiime_otu_tax(file, parseFunction = parse_taxonomy_qiime, verbose = TRUE, parallel = FALSE).gz, etc.), though the details may be OS-specific.
That is, Windows-beware.parse_taxonomy_qiime,
specialized for splitting the ";"-delimited
strings and also attempting to interpret greengenes
prefixes, if any, as that is a common format of the
taxonomy string produced by QIIME.FALSE. Only
a few steps are actually parallelized, and for most
datasets it will actually be faster and more efficient to
keep this set to FALSE. Also, to get any benefit
at all, you will need to register a parallel ``backend''
through one of the backend packages supported by the
foreach-package.$otutab contains the OTU
Table as a numeric matrix, while $taxtab contains
a character matrix of the taxonomy assignments.
importotufile <- system.file("extdata", "GP_otu_table_rand_short.txt.gz", package="phyloseq")
import_qiime_otu_tax(otufile)
Run the code above in your browser using DataLab