eqtaxa
(Required). The species names, or indices,
that should be merged together. If length(eqtaxa) <
2, then the object x will be returned safely
unchanged.
archetype
(Optional). A single-length numeric or
character. The index of eqtaxa, or OTU ID,
indicating the species that should be kept to represent
the summed/merged group of species/taxa/OTUs. The default
is to use the OTU with the largest count total if counts
are available, or to use 1 (the first OTU in
eqtaxa) otherwise. If archetype is not a
valid index or index-name in eqtaxa, the first
will be used, and the value in archetype will be used as
the index-name for the new species.